@@ -69,7 +69,7 @@ class DashboardView(AdminIndexView):
     	else:
     		return render_template("shelf/login/login.html", form=LoginForm(request.form))
 
-    '''@expose('/signup/', methods=("GET", "POST"))
+    @expose('/signup/', methods=("GET", "POST"))
     def signup(self):
         if validate_register_on_submit(request.form):
             return redirect(request.args.get("next") or url_for("admin.signin"))
@@ -81,7 +81,7 @@ class DashboardView(AdminIndexView):
         if validate_recover_on_submit(request.form):
             return redirect(request.args.get("next") or url_for("admin.signin"))
         else:
-    	   return render_template("shelf/login/recover.html", form=RecoverForm(request.form))'''
+    	   return render_template("shelf/login/recover.html", form=RecoverForm(request.form))
 
     @expose('/logout/', methods=("GET",))
     @login_required
