@@ -2,6 +2,9 @@ from flask import Blueprint
 import model
 import admin
 import cache
+import user
+from user.model import User
+from user.view import ShelfUserView
 
 class Shelf:
     def __init__(self, app):
@@ -22,7 +25,17 @@ class Shelf:
 
         self.admin = admin.ShelfAdmin(app, shelf=self)
 
-        self.cache = cache.ShelfCache(app, shelf=self)
+        #self.cache = cache.ShelfCache(app, shelf=self)
+
+        login = user.login
+        login.init_app(app)
+        login.login_view = "admin.signin"
+        self.login = login
+        @self.login.user_loader
+        def load_user(userid):
+            return User.query.get(userid)
+
+        self.admin.add_view(ShelfUserView(User, db.session))
 
         '''shelf_admin = Blueprint('shelf', 'shelf', url_prefix="/shelf", 
             template_folder="templates", static_folder="static")
@@ -34,6 +47,8 @@ class Shelf:
         prepare_model(shelf_computed_model('User'))
         db.create_all()'''
 
+    
+
 
 
 '''
